@@ -77,13 +77,7 @@ class Client:
         try:
             url = "{}/api/secret/{}".format(ServerUrl, name)
             r = requests.get(url=url, headers=HttpHeaderWithJson)
-            if r.status_code is 200:
-                body = r.text
-                return json.loads(body)
-
-
-            print(r.content)
-            return None
+            return self.handleResponse(r)
         except Exception as e:
             print(e)
             return None
@@ -91,12 +85,10 @@ class Client:
     # download secret file and return file path that saved locally
     def downloadSecretFile(self, name, filename):
         try:
-            url = "{}/api/secret/{}/download/{}".format(
-                ServerUrl, name, filename)
-            r = requests.get(url, allow_redirects=True,
-                             headers=HttpHeaderWithJson)
+            url = "{}/api/secret/{}/download/{}".format(ServerUrl, name, filename)
+            r = requests.get(url, allow_redirects=True, headers=HttpHeaderWithJson)
 
-            if r.status_code is 200:
+            if r.status_code == 200:
                 path = os.path.join(self.secretPath, filename)
                 open(path, 'wb').write(r.content)
                 return path
@@ -111,11 +103,7 @@ class Client:
         try:
             url = "{}/api/config/{}".format(ServerUrl, name)
             r = requests.get(url=url, headers=HttpHeaderWithJson)
-            if r.status_code is 200:
-                body = r.text
-                return json.loads(body)
-
-            return None
+            return self.handleResponse(r)
         except Exception as e:
             print(e)
             return None
@@ -124,12 +112,7 @@ class Client:
         try:
             url = "{}/api/flow/{}/users".format(ServerUrl, FlowName)
             r = requests.get(url=url, headers=HttpHeaderWithJson)
-
-            if r.status_code is 200:
-                body = r.text
-                return json.loads(body)
-
-            return None
+            return self.handleResponse(r)
         except Exception as e:
             print(e)
             return None
@@ -150,7 +133,8 @@ class Client:
                 'file': open(path, 'rb'),
                 'body': ('', json.dumps(body), 'application/json')
             })
-            return r.status_code
+
+            return self.handleResponse(r)
         except Exception as e:
             print(e)
             return -1
@@ -172,7 +156,7 @@ class Client:
                 "body": ('', json.dumps(body), 'application/json')
             })
 
-            return r.status_code
+            return self.handleResponse(r)
         except Exception as e:
             print(e)
             return -1
@@ -180,20 +164,35 @@ class Client:
     def sendStatistic(self, body):
         try:
             url = "{}/api/flow/{}/stats".format(ServerUrl, FlowName)
-            r = requests.post(
-                url=url, headers=HttpHeaderWithJson, data=json.dumps(body))
-            return r.status_code
+            r = requests.post(url=url, headers=HttpHeaderWithJson, data=json.dumps(body))
+            return self.handleResponse(r)
         except Exception as e:
             print(e)
             return -1
 
     def addJobContext(self, var):
         try:
-            url = "{}/api/flow/{}/job/{}/context".format(
-                ServerUrl, FlowName, JobBuildNumber)
-            r = requests.post(url=url, headers=HttpHeaderWithJson,
-                              data=json.dumps(var))
-            return r.status_code
+            url = "{}/api/flow/{}/job/{}/context".format(ServerUrl, FlowName, JobBuildNumber)
+            r = requests.post(url=url, headers=HttpHeaderWithJson, data=json.dumps(var))
+            return self.handleResponse(r)
         except Exception as e:
             print(e)
             return -1
+
+    def handleResponse(self, r):
+        if r.status_code != 200:
+            print(r.text)
+            return None
+
+        body = json.loads(r.text)
+        if body["code"] != 200:
+            print(body["message"])
+            return None
+
+        if body["data"] == None:
+            return "success"
+
+        return body["data"]
+
+        
+# print(Client().downloadSecretFile("test", "ios_development.cer"))
\ No newline at end of file
