@@ -32,6 +32,7 @@ JobFinishAt = os.environ.get("FLOWCI_JOB_FINISH_AT")
 JobSteps = os.environ.get("FLOWCI_JOB_STEPS")
 
 AgentToken = os.environ.get('FLOWCI_AGENT_TOKEN')
+AgentWorkspace = os.environ.get('FLOWCI_AGENT_WORKSPACE')
 AgentJobDir = os.environ.get('FLOWCI_AGENT_JOB_DIR')
 
 GitEvent = os.environ.get('FLOWCI_GIT_EVENT')
@@ -56,6 +57,7 @@ GitPrBaseRepoName = os.environ.get('FLOWCI_GIT_PR_BASE_REPO_NAME')
 GitPrBaseRepoBranch = os.environ.get('FLOWCI_GIT_PR_BASE_REPO_BRANCH')
 GitPrBaseRepoCommit = os.environ.get('FLOWCI_GIT_PR_BASE_REPO_COMMIT')
 
+
 class Job:
     def __init__(self):
         self.flowName = FlowName
@@ -71,23 +73,28 @@ class Job:
         self.gitCommit = GitCommit()
         self.gitPr = GitPr()
 
-        if JobStartAt != None and JobFinishAt != None:
+        if self.hasValue(JobStartAt) and self.hasValue(JobFinishAt):
             start = datetime.strptime(JobStartAt, "%Y-%m-%d %H:%M:%S.%f")
             finish = datetime.strptime(JobFinishAt, "%Y-%m-%d %H:%M:%S.%f")
             self.duration = abs(finish - start).microseconds
 
-        if JobSteps != None:
+        if self.hasValue(JobSteps):
             items = JobSteps.split(";")
             for item in items:
                 if item != '':
                     self.steps.append(Step(item))
 
+    def hasValue(self, val):
+        return val != None and val != ''
+
+
 class Step:
     def __init__(self, strItem):
         pair = strItem.split("=")
         self.name = pair[0]
         self.status = pair[1]
 
+
 class GitCommit:
     def __init__(self):
         self.id = GitCommitID
@@ -96,6 +103,7 @@ class GitCommit:
         self.time = GitCommitTime
         self.url = GitCommitURL
 
+
 class GitPr:
     def __init__(self):
         self.title = GitPrTitle
@@ -106,14 +114,16 @@ class GitPr:
         self.head = GitPrHeadRepo()
         self.base = GitPrBaseRepo()
 
+
 class GitPrHeadRepo:
     def __init__(self):
         self.name = GitPrHeadRepoName
         self.branch = GitPrHeadRepoBranch
         self.commit = GitPrHeadRepoCommit
 
+
 class GitPrBaseRepo:
     def __init__(self):
         self.name = GitPrBaseRepoName
         self.branch = GitPrBaseRepoBranch
-        self.commit = GitPrBaseRepoCommit
\ No newline at end of file
+        self.commit = GitPrBaseRepoCommit
